==> senior_design_system-6.0.0.tar.gz: lib/components/senior_calendar/themes/dark/_calendar_theme_dark.dart <==
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../../components.dart';

const calendarDarkTheme = SeniorCalendarThemeData(
  style: SeniorCalendarStyle(
    activeHeaderButtonIconColor: SeniorColors.grayscale0,
    backgroundColor: SeniorColors.grayscale90,
    bottomTextColor: SeniorColors.grayscale0,
    dayColor: SeniorColors.grayscale0,
    headerButtonBorderColor: SeniorColors.grayscale50,
    headerTextColor: SeniorColors.grayscale0,
    inactiveHeaderButtonIconColor: SeniorColors.grayscale50,
    nextMonthDaysBackgroundColor: SeniorColors.grayscale70,
    nextMonthDaysColor: SeniorColors.grayscale50,
    previousMonthDaysBackgroundColor: SeniorColors.grayscale70,
    previousMonthDaysColor: SeniorColors.grayscale50,
    selectedDayBackgroundColor: SeniorColors.primaryColor500,
    selectedDayColor: SeniorColors.grayscale0,
    todayBackgroundColor: SeniorColors.grayscale60,
    todayColor: SeniorColors.grayscale0,
    topLineColor: SeniorColors.neutralColor300,
    topTextColor: SeniorColors.grayscale30,
    weekDaysColor: SeniorColors.grayscale40,
    colorCircleDefaultMarkedDay: SeniorColors.manchesterColorGreen500,
    colorSquareDefaultMarkedDay: SeniorColors.manchesterColorRed500,
    colorTriangleDefaultMarkedDay: SeniorColors.manchesterColorYellow500,
    colorTriangleDownDefaultMarkedDay: SeniorColors.manchesterColorBlue500,
    colorGestureBottom: SeniorColors.neutralColor200,
    colorRangeHighlightBackground: SeniorColors.grayscale70,
    colorDaysRangeHighlight: SeniorColors.grayscale50,
  ),
);

==> senior_design_system-7.0.4.tar.gz: lib/components/senior_calendar/themes/dark/_calendar_theme_dark.dart <==
import 'package:senior_design_tokens/senior_design_tokens.dart';

import '../../../components.dart';

const calendarDarkTheme = SeniorCalendarThemeData(
  style: SeniorCalendarStyle(
    activeHeaderButtonIconColor: SeniorColors.grayscale0,
    backgroundColor: SeniorColors.grayscale90,
    bottomTextColor: SeniorColors.grayscale0,
    dayColor: SeniorColors.grayscale0,
    headerButtonBorderColor: SeniorColors.grayscale50,
    headerTextColor: SeniorColors.grayscale0,
    inactiveHeaderButtonIconColor: SeniorColors.grayscale50,
    nextMonthDaysBackgroundColor: SeniorColors.grayscale70,
    nextMonthDaysColor: SeniorColors.grayscale50,
    previousMonthDaysBackgroundColor: SeniorColors.grayscale70,
    previousMonthDaysColor: SeniorColors.grayscale50,
    selectedDayBackgroundColor: SeniorColors.primaryColor500,
    selectedDayColor: SeniorColors.grayscale0,
    todayBackgroundColor: SeniorColors.grayscale60,
    todayColor: SeniorColors.grayscale0,
    topLineColor: SeniorColors.grayscale30,
    topTextColor: SeniorColors.grayscale30,
    weekDaysColor: SeniorColors.grayscale40,
    colorCircleDefaultMarkedDay: SeniorColors.manchesterColorGreen500,
    colorSquareDefaultMarkedDay: SeniorColors.manchesterColorRed500,
    colorTriangleDefaultMarkedDay: SeniorColors.manchesterColorYellow500,
    colorTriangleDownDefaultMarkedDay: SeniorColors.manchesterColorBlue500,
    colorGestureBottom: SeniorColors.grayscale20,
    colorRangeHighlightBackground: SeniorColors.grayscale70,
    colorDaysRangeHighlight: SeniorColors.grayscale50,
  ),
);
